Documentation
¶
Overview ¶
Package aiservershell provides a pluggable server-side shell for exposing OpenAI-compatible APIs from application-defined Go services.
Protocol handlers are independently constructed from the shared, protocol-neutral backend.Services registry. The root Server is only an optional http.Handler aggregate; applications may serve a protocol handler directly.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
Server is an optional aggregate for independently constructed protocol handlers. It implements http.Handler and does not own network listeners.
type ServerOption ¶
type ServerOption func(*serverConfig) error
ServerOption configures an aggregate Server.
func WithHandler ¶
func WithHandler(pattern string, handler http.Handler) ServerOption
WithHandler mounts one independently constructed protocol handler. Pattern follows http.ServeMux syntax.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package backend defines protocol-neutral application contracts shared by every protocol handler exposed by AI Server Shell.
|
Package backend defines protocol-neutral application contracts shared by every protocol handler exposed by AI Server Shell. |
|
examples
|
|
|
aggregate
command
|
|
|
minimal
command
|
|
|
internal
|
|
|
cmd/openai-gen
command
|
|
|
Package openai provides the OpenAI-compatible protocol handler.
|
Package openai provides the OpenAI-compatible protocol handler. |
|
internal/profile
Code generated by internal/cmd/openai-gen; DO NOT EDIT.
|
Code generated by internal/cmd/openai-gen; DO NOT EDIT. |